summaryrefslogtreecommitdiffstats
path: root/src/com
diff options
context:
space:
mode:
authorBen Murdoch <benm@google.com>2010-07-16 12:42:22 +0100
committerBen Murdoch <benm@google.com>2010-07-16 12:42:22 +0100
commitb50d7403816f316fdcaf5b5a318383e64f1a8775 (patch)
tree70ca2663e6546cc175b71306d9d5d591a3f3e464 /src/com
parentb4fb25cb5bb9231ea5f1e0d4f950bf89cf617ba7 (diff)
downloadpackages_apps_Browser-b50d7403816f316fdcaf5b5a318383e64f1a8775.zip
packages_apps_Browser-b50d7403816f316fdcaf5b5a318383e64f1a8775.tar.gz
packages_apps_Browser-b50d7403816f316fdcaf5b5a318383e64f1a8775.tar.bz2
Capture API updates from new specification
http://dev.w3.org/2009/dap/camera/ Replace "source" with "capture" and "gallery" with "filesystem". Change-Id: I6b95d2a24c8e8795e4cab62a023511047bb6ea26
Diffstat (limited to 'src/com')
-rw-r--r--src/com/android/browser/BrowserActivity.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/com/android/browser/BrowserActivity.java b/src/com/android/browser/BrowserActivity.java
index 72a4210..dde0765 100644
--- a/src/com/android/browser/BrowserActivity.java
+++ b/src/com/android/browser/BrowserActivity.java
@@ -2888,9 +2888,9 @@ public class BrowserActivity extends Activity
final String imageMimeType = "image/*";
final String videoMimeType = "video/*";
- final String mediaSourceKey = "source";
+ final String mediaSourceKey = "capture";
final String mediaSourceValueCamera = "camera";
- final String mediaSourceValueGallery = "gallery";
+ final String mediaSourceValueFileSystem = "filesystem";
final String mediaSourceValueCamcorder = "camcorder";
// media source can be 'gallery' or 'camera' or 'camcorder'
@@ -2951,8 +2951,8 @@ public class BrowserActivity extends Activity
// directly.
BrowserActivity.this.startActivityForResult(cameraIntent, FILE_SELECTED);
return;
- } else if (mediaSource.equals(mediaSourceValueGallery)) {
- // Specified gallery as the source, so don't want to consider the camera.
+ } else if (mediaSource.equals(mediaSourceValueFileSystem)) {
+ // Specified filesytem as the source, so don't want to consider the camera.
addCameraIntent = false;
}
} else if (mimeType.equals(videoMimeType)) {
@@ -2967,8 +2967,8 @@ public class BrowserActivity extends Activity
// directly.
BrowserActivity.this.startActivityForResult(camcorderIntent, FILE_SELECTED);
return;
- } else if (mediaSource.equals(mediaSourceValueGallery)) {
- // Specified gallery as the source, so don't want to consider the camcorder.
+ } else if (mediaSource.equals(mediaSourceValueFileSystem)) {
+ // Specified filesystem as the source, so don't want to consider the camcorder.
addCamcorderIntent = false;
}
} else {